@@ -6,7 +6,6 @@ from __future__ import absolute_import
 
 import sys
 import os
-import shutil
 import tempfile
 import site
 import contextlib
@@ -16,7 +15,6 @@ import itertools
 import distutils.errors
 import io
 
-from setuptools.extern import six
 from setuptools.extern.six.moves import urllib
 import time
 
@@ -38,11 +36,12 @@ import setuptools.tests.server
 import pkg_resources
 
 from .py26compat import tarfile_open
-from . import contexts, is_ascii
+from . import contexts
 from .textwrap import DALS
 
 
 class FakeDist(object):
+
     def get_entry_map(self, group):
         if group != 'console_scripts':
             return {}
@@ -57,19 +56,16 @@ SETUP_PY = DALS("""
     setup(name='foo')
     """)
 
+
 class TestEasyInstallTest:
 
-    def test_install_site_py(self):
+    def test_install_site_py(self, tmpdir):
         dist = Distribution()
         cmd = ei.easy_install(dist)
         cmd.sitepy_installed = False
-        cmd.install_dir = tempfile.mkdtemp()
-        try:
-            cmd.install_site_py()
-            sitepy = os.path.join(cmd.install_dir, 'site.py')
-            assert os.path.exists(sitepy)
-        finally:
-            shutil.rmtree(cmd.install_dir)
+        cmd.install_dir = str(tmpdir)
+        cmd.install_site_py()
+        assert (tmpdir / 'site.py').exists()
 
     def test_get_script_args(self):
         header = ei.CommandSpec.best().from_environment().as_header()
@@ -124,8 +120,22 @@ class TestEasyInstallTest:
         with pytest.raises(distutils.errors.DistutilsError):
             cmd.cant_write_to_target()
 
+    def test_all_site_dirs(self, monkeypatch):
+        """
+        get_site_dirs should always return site dirs reported by
+        site.getsitepackages.
+        """
+        mock_gsp = lambda: ['/setuptools/test/site-packages']
+        monkeypatch.setattr(site, 'getsitepackages', mock_gsp, raising=False)
+        assert '/setuptools/test/site-packages' in ei.get_site_dirs()
+
+    def test_all_site_dirs_works_without_getsitepackages(self, monkeypatch):
+        monkeypatch.delattr(site, 'getsitepackages', raising=False)
+        assert ei.get_site_dirs()
+
 
 class TestPTHFileWriter:
+
     def test_add_from_cwd_site_sets_dirty(self):
         '''a pth file manager should set dirty
         if a distribution is in site but also the cwd
@@ -259,6 +269,7 @@ def distutils_package():
 
 
 class TestDistutilsPackage:
+
     def test_bdist_egg_available_on_distutils_pkg(self, distutils_package):
         run_setup('setup.py', ['bdist_egg'])
 
@@ -550,6 +561,7 @@ class TestScriptHeader:
 
 
 class TestCommandSpec:
+
     def test_custom_launch_command(self):
         """
         Show how a custom CommandSpec could be used to specify a #! executable
@@ -594,6 +606,7 @@ class TestCommandSpec:
 
 
 class TestWindowsScriptWriter:
+
     def test_header(self):
         hdr = ei.WindowsScriptWriter.get_script_header('')
         assert hdr.startswith('#!')
